/*********************************************************************************
The following model is assumed: 

        Y_t = X_t'*beta + U_t,

    where 

    1) Y is 1 * 1 scalar;
    2) X is k * 1 vector;
    3) beta is k * 1 vector; and
    4) U is 1 * 1 scalar such that U ~ N(0, sigma^2).

The unknown parameters are estimated by the MLE method. 
Given this, the following program computes two statistics:

    1) IMT tests defined by Cho and White (2011):

        b1, b2, and b3

       as defined by Cho and White (2011).  

    2) Estimated p-values of the tests by parametric bootstrap:

        pv1, pv2, pv3

       as explained in Cho and White (2011).

November 20, 2011
Jin Seo Cho
**************************************************************************************/
new;
library pgraph;
#include trc.prc;
#include imts_linorm.prc;
#include imts_linorm_pb.prc;

nnn = 200;                                  /* sample size */
bbb = 100;                                  /* number of bootstrapping */

xxx = rndn(nnn,2);                          /* provide explanatory variables */ 
uuu = rndn(nnn,1);
yyy = 0.5 + xxx*ones(2,1) + uuu;            /* provide dependent variable */
ind = ones(nnn,1)~xxx;                      /* provide set of independent variables */ 

dta = yyy~ind;                              /* provide data in the form of (dependent variable)~(independent variable) */ 
{b1, b2, b3, pame} = imts_linorm(dta);      /* computes the test statistics and estimated parameters */ 
{pv1, pv2, pv3} = imts_linorm_pb(dta,bbb);  /* computes the p-values of the test statistics */


print "===============================================";
print "Linear Normal Model                            ";
print "===============================================";
print "Computed test statsitics values"; 
print "===============================================";
print "Test Statistic B_1 =           " b1;
print "Test Statistic B_2 =           " b2;
print "Test Statistic B_3 =           " b3;
print "===============================================";
print "Computed P-values of test statsitics"; 
print "===============================================";
print "P-value of Test Statistic B_1 =" pv1;
print "P-value of Test Statistic B_2 =" pv2;
print "P-value of Test Statistic B_3 =" pv3;
print "===============================================";
